--
-- SkeenStunWatch
-- 

-- Local table (used to store functions, ect)
local SkeenStunWatch = {}
SkeenStunWatch.bars = 0 -- The number of bars active
SkeenStunWatch.stuns = {}

local LibSkeenCore = LibStub("LibSkeenCore");

SkeenStunWatch.eventHandler = CreateFrame("Frame")
SkeenStunWatch.eventHandler:SetScript("OnEvent", function(this, event, ...) SkeenStunWatch.events[event](...) end)
--Events to listen to
SkeenStunWatch.eventHandler:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
SkeenStunWatch.eventHandler:RegisterEvent("ADDON_LOADED") 
--EventHandler Functions
--by our eventHandler frame.
SkeenStunWatch.events = {}
--Player logged in
function SkeenStunWatch.events.ADDON_LOADED(addon)
    if (addon ~= "SkeenStunWatch") then
        return
    end
    
    SkeenStunWatch:PrepareDatabase()
    SkeenStunWatch:CreateGUI()
    SkeenStunWatch:UpdateDragability()
    SkeenStunWatch:CreateOptionFrame()
end

-- Prepare the Normal database (settings database)
-- This is the maintained database, and isn't wiped on each login, like the active one is
function SkeenStunWatch:PrepareDatabase()
    -- If there doesn't exist a database currently
    if SkeenStunWatchDatabase == nil then --if u add more, check the addon version and update database
        SkeenStunWatchDatabase = {} -- fresh start
    end

    local default_values = {
        scale=1,
        locked=false,
        bar_width=100,
        Kidney=true,
        Gouge=true,
        Sap=true,
        Blind=true,
        CheapShot=true,
        GarroteSilence=true,
        KickSilence=false,
        DeadlyThrow=false,
        BarDropDown=true,
        update_interval=0.1
    }
    for k,v in pairs(default_values) do
        if(SkeenStunWatchDatabase[k] == nil) then
            SkeenStunWatchDatabase[k] = v
        end
    end
end

function SkeenStunWatch.events.COMBAT_LOG_EVENT_UNFILTERED( timestamp, event, unknown,
                                                            sourceGUID, sourceName, sourceFlags, sourceFlags2,
                                                            destGUID, destName, destFlags, destFlags2,
                                                            spellID, spellName, spellSchool) 
    -- Check that the player is the source
    -- That the spell is a rogue stun
    -- 408 = Kidney, 1776 = Gouge, 6770 = Sap, 2094 = Blind, 1833 = Cheap Shot,
    -- 1330 = Garrote's Silence, 86759 = Kick's Silenced, 32748 = Deadly Throw's
    -- Silence
    if (sourceGUID == UnitGUID("player")) and
        (
            ((spellID == 408) and SkeenStunWatch:GetKidney()) or
            ((spellID == 1776) and SkeenStunWatch:GetGouge()) or
            ((spellID == 6770) and SkeenStunWatch:GetSap()) or
            ((spellID == 2094) and SkeenStunWatch:GetBlind()) or
            ((spellID == 1833) and SkeenStunWatch:GetCheapShot()) or 
            ((spellID == 1330) and SkeenStunWatch:GetGarroteSilence()) or 
            ((spellID == 86759) and SkeenStunWatch:GetKickSilence()) or 
            ((spellID == 32748) and SkeenStunWatch:GetDeadlyThrowSilence())
        ) then
        if(event == "SPELL_AURA_APPLIED") then
            local stun = {}
            stun.start = GetTime()
            stun.spell = spellID
            stun.spellName = spellName
            stun.target = destGUID
            stun.targetName = destName
            stun.duration = LibSkeenCore:GetDebuffDuration(spellID)

            local i = 0
            while(SkeenStunWatch.stuns[i] ~= nil) do
                i = i + 1
            end
            SkeenStunWatch.stuns[i] = stun
            SkeenStunWatch:CreateBar(stun)
        end
        if(event == "SPELL_AURA_REMOVED") then
            SkeenStunWatch:Remove(spellID, destGUID)
        end
        if(event == "SPELL_AURA_REFRESH") then
            SkeenStunWatch:UpdateDuration(spellID, destGUID, GetTime(), LibSkeenCore:GetDebuffDuration(spellID))
        end
    end
end

-- Functions Section
function SkeenStunWatch_OnUpdate(self, elapsed)
    self.TimeSinceLastUpdate = self.TimeSinceLastUpdate + elapsed; 	

    if (self.TimeSinceLastUpdate > SkeenStunWatch:GetUpdateInterval()) then
        SkeenStunWatch:Update(GetTime())
        self.TimeSinceLastUpdate = 0;
    end
end

function SkeenStunWatch:UpdateDuration(spellID, destGUID, time, duration)
    local i = 0
    while(SkeenStunWatch.stuns[i] ~= nil) do
        if(SkeenStunWatch.stuns[i].spell == spellID) and (SkeenStunWatch.stuns[i].target == destGUID) then
            SkeenStunWatch.stuns[i].start = time
            SkeenStunWatch.stuns[i].duration = duration
        end
        i = i + 1
    end
end 

function SkeenStunWatch:Remove(spellID, destGUID)
    local i = 0
    while(SkeenStunWatch.stuns[i] ~= nil) do
        if(SkeenStunWatch.stuns[i].spell == spellID) and (SkeenStunWatch.stuns[i].target == destGUID) then
            SkeenStunWatch:RemoveBar(SkeenStunWatch.stuns[i])
            while(SkeenStunWatch.stuns[i+1] ~= nil) do
                SkeenStunWatch.stuns[i] = SkeenStunWatch.stuns[i+1]
                i = i + 1
            end
            SkeenStunWatch.stuns[i] = nil
        end
        i = i + 1
    end
end

function SkeenStunWatch:Update(timestamp)
    local i = 0
    while(SkeenStunWatch.stuns[i] ~= nil) do
        SkeenStunWatch:UpdateBar(SkeenStunWatch.stuns[i], timestamp)
        i = i + 1
    end
end

function SkeenStunWatch:UpdateBar(stun, timestamp)
    local duration_elapsed = timestamp - stun.start
    local duration_left = stun.duration - duration_elapsed
    if(duration_left < 0) then
        SkeenStunWatch:Remove(stun.spell, stun.target)
    end
    local precentage = (duration_left/stun.duration)
    stun.process:SetValue(precentage*100)
    stun.string:SetText(format("%s :: %.1f --> %s", stun.spellName, duration_left, stun.targetName))
end

function SkeenStunWatch:CreateBar(stun)
    local bar = CreateFrame("Frame", nil, SkeenStunWatch.displayFrame)
    bar:SetWidth(SkeenStunWatchDatabase.bar_width)
    bar:SetHeight(26)
    local prefix = nil
    if(SkeenStunWatch:GetBarDropDown()) then
        prefix = -1
    else
        prefix = 1
    end
    bar:SetPoint("TOPLEFT", 0, prefix*(20*SkeenStunWatch.bars))

	local background = bar:CreateTexture("Background", "BACKGROUND")
	background:SetSize(SkeenStunWatchDatabase.bar_width-9, 13)
	background:SetTexture(0, 0, 0, .5)
	background:SetPoint("TOP", 0, -2)

    local border = bar:CreateTexture("Border", "OVERLAY")
	border:SetWidth(SkeenStunWatchDatabase.bar_width-5)
    border:SetHeight(20)
	border:SetTexture("Interface\\Tooltips\\UI-StatusBar-Border")
	border:SetPoint("TOP", 0, 2)

    local process =  CreateFrame("StatusBar", "$parent_current", bar)
    process:SetWidth(SkeenStunWatchDatabase.bar_width-11)
    process:SetHeight(13)
    process:SetPoint("TOP", 0, -2)

    local process_texture = process:CreateTexture("Background", "BACKGROUND")
	process_texture:SetTexture("Interface\\TargetingFrame\\UI-StatusBar")

    process:SetStatusBarTexture(process_texture)
    process:SetStatusBarColor(1, 1, 0)
    process:SetMinMaxValues(0, 100)
	process:SetFrameLevel(process:GetParent():GetFrameLevel())

    local string = bar:CreateFontString("Frame_String","OVERLAY","GameFontHighlight")
    string:SetText(format("%s :: %.1f --> %s", stun.spellName, stun.duration, stun.targetName))
    string:SetWidth(SkeenStunWatchDatabase.bar_width-6)
    string:SetHeight(16)
    string:SetPoint("TOP", 0, 0)

    stun.bar = bar
    stun.process = process
    stun.string = string
    SkeenStunWatch.bars = SkeenStunWatch.bars + 1
end

function SkeenStunWatch:RemoveBar(stun)
    stun.bar:Hide()
    stun.bar:SetParent(nil)
 
    SkeenStunWatch.bars = SkeenStunWatch.bars - 1
end

function SkeenStunWatch:CreateGUI()
    local displayFrame = CreateFrame("Frame", nil, UIParent)
    displayFrame:SetFrameStrata("BACKGROUND")
    displayFrame:SetBackdrop({bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = true, tileSize = 32,})
    displayFrame:SetClampedToScreen(true)
    displayFrame:SetMovable(true)
    displayFrame:ClearAllPoints()
    displayFrame:SetWidth(SkeenStunWatchDatabase.bar_width)
    displayFrame:SetHeight(20)
   
    if SkeenStunWatchDatabase.bottom == nil or SkeenStunWatchDatabase.left == nil then
        displayFrame:SetPoint("CENTER")
        SkeenStunWatchDatabase.locked = false
    else
        displayFrame:SetPoint("BOTTOMLEFT", SkeenStunWatchDatabase.left, SkeenStunWatchDatabase.bottom)
    end
    
    SkeenStunWatch.displayFrame = displayFrame

    displayFrame:SetScale(SkeenStunWatchDatabase.scale)
end

-- The optionsframe in interface
function SkeenStunWatch:CreateOptionFrame()

    local panel = CreateFrame("FRAME", "SkeenStunWatchOptions", UIParent);
    panel.name = "SkeenStunWatch";

    local fstring1 = panel:CreateFontString("SkeenStunWatchOptions_string1","OVERLAY","GameFontNormal")
    fstring1:SetText("Lock")
    fstring1:SetPoint("TOPLEFT", 10, -10)

    local checkbox1 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox1:SetWidth(18)
    checkbox1:SetHeight(18)
    checkbox1:SetScript("OnClick", function() SkeenStunWatch:ToggleLocked() end)
    checkbox1:SetPoint("TOPRIGHT", -10, -10)
    checkbox1:SetChecked(SkeenStunWatch:GetLocked())

    local fstring2 = panel:CreateFontString("SkeenStunWatchOptions_string2","OVERLAY","GameFontNormal")
    fstring2:SetText("GUI Scale")
    fstring2:SetPoint("TOPLEFT", 10, -40)

    local slider2 = CreateFrame("Slider", "$parent_sl2", panel, "OptionsSliderTemplate")
    slider2:SetMinMaxValues(.5, 1.5)
    slider2:SetValue(SkeenStunWatch:GetScale())
    slider2:SetValueStep(.05)
    slider2:SetScript("OnValueChanged", function(self) SkeenStunWatch:SetScale(self:GetValue()); end) --getglobal(self:GetName() .. "Text"):SetText(string.format("%.0f%%", self:GetValue()*100))  end)
    --getglobal(slider2:GetName() .. "Low"):SetText("50%")
    --getglobal(slider2:GetName() .. "High"):SetText("150%")
    --getglobal(slider2:GetName() .. "Text"):SetText(string.format("%.0f%%", SkeenStunWatch:GetScale()*100))
    slider2:SetPoint("TOPRIGHT", -10, -40)

    local fstring3 = panel:CreateFontString("SkeenStunWatchOptions_string3","OVERLAY","GameFontNormal")
    fstring3:SetText("Bar width")
    fstring3:SetPoint("TOPLEFT", 10, -70)

    local slider3 = CreateFrame("Slider", "$parent_sl2", panel, "OptionsSliderTemplate")
    slider3:SetMinMaxValues(50, 400)
    slider3:SetValue(SkeenStunWatch:GetBarWidth())
    slider3:SetValueStep(10)
    slider3:SetScript("OnValueChanged", function(self) SkeenStunWatch:SetBarWidth(self:GetValue()); end)-- getglobal(self:GetName() .. "Text"):SetText(string.format("%.0f%%", self:GetValue()*100))  end)
    --getglobal(slider3:GetName() .. "Low"):SetText("50%")
    --getglobal(slider3:GetName() .. "High"):SetText("400%")
    --getglobal(slider3:GetName() .. "Text"):SetText(string.format("%.0f%%", SkeenStunWatch:GetBarWidth()*100))
    slider3:SetPoint("TOPRIGHT", -10, -70)

    local fstring35 = panel:CreateFontString("SkeenStunWatchOptions_string35","OVERLAY","GameFontNormal")
    fstring35:SetText("Update Interval (sec)")
    fstring35:SetPoint("TOPLEFT", 10, -110)

    local slider35 = CreateFrame("Slider", "$parent_sl3", panel, "OptionsSliderTemplate")
    slider35:SetMinMaxValues(0, 1)
    slider35:SetValue(SkeenStunWatch:GetUpdateInterval())
    slider35:SetValueStep(.1)
    slider35:SetScript("OnValueChanged", function(self) SkeenStunWatch:SetUpdateInterval(self:GetValue()); end) --getglobal(self:GetName() .. "Text"):SetText(string.format("%.1f", self:GetValue()))  end)
    --getglobal(slider3:GetName() .. "Low"):SetText("0")
    --getglobal(slider3:GetName() .. "High"):SetText("1")
    --getglobal(slider3:GetName() .. "Text"):SetText(string.format("%.1f", SkeenMelee:GetUpdateInterval()))
    slider35:SetPoint("TOPRIGHT", -10, -110)

    local fstring4 = panel:CreateFontString("SkeenStunWatchOptions_string4","OVERLAY","GameFontNormal")
    fstring4:SetText("Detect Kidney")
    fstring4:SetPoint("TOPLEFT", 10, -150)

    local checkbox4 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox4:SetWidth(18)
    checkbox4:SetHeight(18)
    checkbox4:SetScript("OnClick", function() SkeenStunWatch:ToggleKidney() end)
    checkbox4:SetPoint("TOPRIGHT", -10, -150)
    checkbox4:SetChecked(SkeenStunWatch:GetKidney())

    local fstring5 = panel:CreateFontString("SkeenStunWatchOptions_string5","OVERLAY","GameFontNormal")
    fstring5:SetText("Detect Gouge")
    fstring5:SetPoint("TOPLEFT", 10, -170)

    local checkbox5 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox5:SetWidth(18)
    checkbox5:SetHeight(18)
    checkbox5:SetScript("OnClick", function() SkeenStunWatch:ToggleGouge() end)
    checkbox5:SetPoint("TOPRIGHT", -10, -170)
    checkbox5:SetChecked(SkeenStunWatch:GetGouge())

    local fstring6 = panel:CreateFontString("SkeenStunWatchOptions_string6","OVERLAY","GameFontNormal")
    fstring6:SetText("Detect Sap")
    fstring6:SetPoint("TOPLEFT", 10, -190)

    local checkbox6 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox6:SetWidth(18)
    checkbox6:SetHeight(18)
    checkbox6:SetScript("OnClick", function() SkeenStunWatch:ToggleSap() end)
    checkbox6:SetPoint("TOPRIGHT", -10, -190)
    checkbox6:SetChecked(SkeenStunWatch:GetSap())

    local fstring7 = panel:CreateFontString("SkeenStunWatchOptions_string7","OVERLAY","GameFontNormal")
    fstring7:SetText("Detect Blind")
    fstring7:SetPoint("TOPLEFT", 10, -210)

    local checkbox7 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox7:SetWidth(18)
    checkbox7:SetHeight(18)
    checkbox7:SetScript("OnClick", function() SkeenStunWatch:ToggleBlind() end)
    checkbox7:SetPoint("TOPRIGHT", -10, -210)
    checkbox7 :SetChecked(SkeenStunWatch:GetBlind())
    
    local fstring8 = panel:CreateFontString("SkeenStunWatchOptions_string8","OVERLAY","GameFontNormal")
    fstring8:SetText("Detect Cheap Shot")
    fstring8:SetPoint("TOPLEFT", 10, -230)

    local checkbox8 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox8:SetWidth(18)
    checkbox8:SetHeight(18)
    checkbox8:SetScript("OnClick", function() SkeenStunWatch:ToggleCheapShot() end)
    checkbox8:SetPoint("TOPRIGHT", -10, -230)
    checkbox8:SetChecked(SkeenStunWatch:GetCheapShot())

    local fstring9 = panel:CreateFontString("SkeenStunWatchOptions_string9","OVERLAY","GameFontNormal")
    fstring9:SetText("Detect Garrote Silence")
    fstring9:SetPoint("TOPLEFT", 10, -250)

    local checkbox9 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox9:SetWidth(18)
    checkbox9:SetHeight(18)
    checkbox9:SetScript("OnClick", function() SkeenStunWatch:ToggleGarroteSilence() end)
    checkbox9:SetPoint("TOPRIGHT", -10, -250)
    checkbox9:SetChecked(SkeenStunWatch:GetGarroteSilence())

    local fstring10 = panel:CreateFontString("SkeenStunWatchOptions_string10","OVERLAY","GameFontNormal")
    fstring10:SetText("Detect Kick Silence")
    fstring10:SetPoint("TOPLEFT", 10, -270)

    local checkbox10 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox10:SetWidth(18)
    checkbox10:SetHeight(18)
    checkbox10:SetScript("OnClick", function() SkeenStunWatch:ToggleKickSilence() end)
    checkbox10:SetPoint("TOPRIGHT", -10, -270)
    checkbox10:SetChecked(SkeenStunWatch:GetKickSilence())

    local fstring11 = panel:CreateFontString("SkeenStunWatchOptions_string11","OVERLAY","GameFontNormal")
    fstring11:SetText("Detect Deadly Throw Silence")
    fstring11:SetPoint("TOPLEFT", 10, -290)

    local checkbox11 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox11:SetWidth(18)
    checkbox11:SetHeight(18)
    checkbox11:SetScript("OnClick", function() SkeenStunWatch:ToggleDeadlyThrowSilence() end)
    checkbox11:SetPoint("TOPRIGHT", -10, -290)
    checkbox11:SetChecked(SkeenStunWatch:GetDeadlyThrowSilence())

    local fstring12 = panel:CreateFontString("SkeenStunWatchOptions_string12","OVERLAY","GameFontNormal")
    fstring12:SetText("Bar drop down")
    fstring12:SetPoint("TOPLEFT", 10, -310)

    local checkbox12 = CreateFrame("CheckButton", "$parent_cb1", panel, "OptionsCheckButtonTemplate")
    checkbox12:SetWidth(18)
    checkbox12:SetHeight(18)
    checkbox12:SetScript("OnClick", function() SkeenStunWatch:ToggleBarDropDown() end)
    checkbox12:SetPoint("TOPRIGHT", -10, -310)
    checkbox12:SetChecked(SkeenStunWatch:GetBarDropDown())

    SkeenStunWatch.options = panel
    panel.parent = "Skeen"

    InterfaceOptions_AddCategory(panel);
end

function SkeenStunWatch:GetLocked()
    return SkeenStunWatchDatabase.locked
end

function SkeenStunWatch:ToggleLocked()
    SkeenStunWatchDatabase.locked = not SkeenStunWatchDatabase.locked
    SkeenStunWatch:UpdateDragability()
end

function SkeenStunWatch:GetKidney()
    return SkeenStunWatchDatabase.Kidney
end

function SkeenStunWatch:ToggleKidney()
    SkeenStunWatchDatabase.Kidney = not SkeenStunWatchDatabase.Kidney
end

function SkeenStunWatch:GetGouge()
    return SkeenStunWatchDatabase.Gouge
end

function SkeenStunWatch:ToggleGouge()
    SkeenStunWatchDatabase.Gouge = not SkeenStunWatchDatabase.Gouge
end

function SkeenStunWatch:GetSap()
    return SkeenStunWatchDatabase.Sap
end

function SkeenStunWatch:ToggleSap()
    SkeenStunWatchDatabase.Sap = not SkeenStunWatchDatabase.Sap
end

function SkeenStunWatch:GetBlind()
    return SkeenStunWatchDatabase.Blind
end

function SkeenStunWatch:ToggleBlind()
    SkeenStunWatchDatabase.Blind = not SkeenStunWatchDatabase.Blind
end

function SkeenStunWatch:GetCheapShot()
    return SkeenStunWatchDatabase.CheapShot
end

function SkeenStunWatch:ToggleCheapShot()
    SkeenStunWatchDatabase.CheapShot = not SkeenStunWatchDatabase.CheapShot
end

function SkeenStunWatch:GetGarroteSilence()
    return SkeenStunWatchDatabase.CheapShot
end

function SkeenStunWatch:ToggleGarroteSilence()
    SkeenStunWatchDatabase.GarroteSilence = not SkeenStunWatchDatabase.GarroteSilence
end

function SkeenStunWatch:GetKickSilence()
    return SkeenStunWatchDatabase.CheapShot
end

function SkeenStunWatch:ToggleKickSilence()
    SkeenStunWatchDatabase.KickSilence = not SkeenStunWatchDatabase.KickSilence
end

function SkeenStunWatch:GetDeadlyThrowSilence()
    return SkeenStunWatchDatabase.DeadlyThrow
end

function SkeenStunWatch:ToggleDeadlyThrowSilence()
    SkeenStunWatchDatabase.DeadlyThrow = not SkeenStunWatchDatabase.DeadlyThrow
end

function SkeenStunWatch:GetBarDropDown()
    return SkeenStunWatchDatabase.BarDropDown
end

function SkeenStunWatch:ToggleBarDropDown()
    SkeenStunWatchDatabase.BarDropDown = not SkeenStunWatchDatabase.BarDropDown
end

function SkeenStunWatch:GetScale()
    return SkeenStunWatchDatabase.scale
end

function SkeenStunWatch:SetScale(num)
    SkeenStunWatchDatabase.scale = num
    SkeenStunWatch.displayFrame:SetScale(SkeenStunWatchDatabase.scale)
end

function SkeenStunWatch:GetUpdateInterval()
    return SkeenStunWatchDatabase.update_interval
end

function SkeenStunWatch:SetUpdateInterval(num)
    SkeenStunWatchDatabase.update_interval = num
end

function SkeenStunWatch:GetBarWidth()
    return SkeenStunWatchDatabase.bar_width
end

function SkeenStunWatch:SetBarWidth(num)
    SkeenStunWatchDatabase.bar_width = num
    SkeenStunWatch.displayFrame:SetWidth(SkeenStunWatchDatabase.bar_width)
end

function SkeenStunWatch:UpdateDragability()
    if SkeenStunWatchDatabase.locked then
        SkeenStunWatch.displayFrame:SetScript("OnMouseDown", nil)
        SkeenStunWatch.displayFrame:SetScript("OnMouseUp", nil)
        SkeenStunWatch.displayFrame:SetScript("OnDragStop", nil)
        SkeenStunWatch.displayFrame:SetBackdropColor(0, 0, 0, 0)
        SkeenStunWatch.displayFrame:EnableMouse(false)
    else
        SkeenStunWatch.displayFrame:SetScript("OnMouseDown", function(self) self:StartMoving() end)
        SkeenStunWatch.displayFrame:SetScript("OnMouseUp", function(self) self:StopMovingOrSizing(); SkeenStunWatchDatabase.bottom = SkeenStunWatch.displayFrame:GetBottom(); SkeenStunWatchDatabase.left = SkeenStunWatch.displayFrame:GetLeft(); end)
        SkeenStunWatch.displayFrame:SetScript("OnDragStop", function(self) self:StopMovingOrSizing(); SkeenStunWatchDatabase.bottom = SkeenStunWatch.displayFrame:GetBottom(); SkeenStunWatchDatabase.left = SkeenStunWatch.displayFrame:GetLeft(); end)
        SkeenStunWatch.displayFrame:SetBackdropColor(0, 0, 0, .4)
        SkeenStunWatch.displayFrame:EnableMouse(true)
    end
end

function SkeenStunWatch:HideFrame()
    SkeenStunWatch.displayFrame:Hide()
    SkeenStunWatch.infoString:Hide()
end

function SkeenStunWatch:ShowFrame()
    SkeenStunWatch.displayFrame:Show()
    SkeenStunWatch.infoString:Show()
end
